@@ -1,5 +1,5 @@
-//args: -Eerrcheck
-//config_path: testdata/errcheck/exclude_functions.yml
+//golangcitest:args -Eerrcheck
+//golangcitest:config_path testdata/configs/exclude_functions.yml
 package testdata
 
 import (
@@ -13,6 +13,6 @@ func TestErrcheckExcludeFunctions() []byte {
 }
 
 func TestErrcheckNoExcludeFunctions() []byte {
-	ret, _ := ioutil.ReadAll(nil) // ERROR "Error return value of `ioutil.ReadAll` is not checked"
+	ret, _ := ioutil.ReadAll(nil) // want "Error return value of `ioutil.ReadAll` is not checked"
 	return ret
 }
